@@ -3,17 +3,14 @@ pub mod state_abbreviations;
 
 pub mod case_name_part_abbreviations;
 
-pub mod laws;
 pub mod journals;
+pub mod laws;
 
-mod regexes;
-
-mod utils;
-
-pub use regexes::{RegexTemplate, regexes};
+pub mod regexes;
+pub mod utils;
 
 #[derive(Debug, Clone, thiserror::Error)]
 pub enum Error {
-  #[error("Failed to resolve regex because there was too much recursion in the templates")]
-  TooMuchRecursion
+    #[error("Failed to resolve regex because there was too much recursion in the templates")]
+    TooMuchRecursion,
 }
